from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.LibraryLoader
FIND_RESOURCE_DIRECTORY_TYPES: UInt32 = 256
FIND_RESOURCE_DIRECTORY_NAMES: UInt32 = 512
FIND_RESOURCE_DIRECTORY_LANGUAGES: UInt32 = 1024
RESOURCE_ENUM_LN: UInt32 = 1
RESOURCE_ENUM_MUI: UInt32 = 2
RESOURCE_ENUM_MUI_SYSTEM: UInt32 = 4
RESOURCE_ENUM_VALIDATE: UInt32 = 8
RESOURCE_ENUM_MODULE_EXACT: UInt32 = 16
SUPPORT_LANG_NUMBER: UInt32 = 32
GET_MODULE_HANDLE_EX_FLAG_PIN: UInt32 = 1
GET_MODULE_HANDLE_EX_FLAG_UNCHANGED_REFCOUNT: UInt32 = 2
GET_MODULE_HANDLE_EX_FLAG_FROM_ADDRESS: UInt32 = 4
CURRENT_IMPORT_REDIRECTION_VERSION: UInt32 = 1
LOAD_LIBRARY_OS_INTEGRITY_CONTINUITY: UInt32 = 32768
@winfunctype('KERNEL32.dll')
def DisableThreadLibraryCalls(hLibModule: win32more.Windows.Win32.Foundation.HMODULE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def FindResourceExW(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PWSTR, lpName: win32more.Windows.Win32.Foundation.PWSTR, wLanguage: UInt16) -> win32more.Windows.Win32.Foundation.HRSRC: ...
FindResourceEx = UnicodeAlias('FindResourceExW')
@winfunctype('KERNEL32.dll')
def FreeLibraryAndExitThread(hLibModule: win32more.Windows.Win32.Foundation.HMODULE, dwExitCode: UInt32) -> Void: ...
@winfunctype('KERNEL32.dll')
def FreeResource(hResData: win32more.Windows.Win32.Foundation.HGLOBAL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetModuleFileNameA(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpFilename: win32more.Windows.Win32.Foundation.PSTR, nSize: UInt32) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetModuleFileNameW(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpFilename: win32more.Windows.Win32.Foundation.PWSTR, nSize: UInt32) -> UInt32: ...
GetModuleFileName = UnicodeAlias('GetModuleFileNameW')
@winfunctype('KERNEL32.dll')
def GetModuleHandleA(lpModuleName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HMODULE: ...
@winfunctype('KERNEL32.dll')
def GetModuleHandleW(lpModuleName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HMODULE: ...
GetModuleHandle = UnicodeAlias('GetModuleHandleW')
@winfunctype('KERNEL32.dll')
def GetModuleHandleExA(dwFlags: UInt32, lpModuleName: win32more.Windows.Win32.Foundation.PSTR, phModule: POINTER(win32more.Windows.Win32.Foundation.HMODULE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def GetModuleHandleExW(dwFlags: UInt32, lpModuleName: win32more.Windows.Win32.Foundation.PWSTR, phModule: POINTER(win32more.Windows.Win32.Foundation.HMODULE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
GetModuleHandleEx = UnicodeAlias('GetModuleHandleExW')
@winfunctype('KERNEL32.dll')
def GetProcAddress(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpProcName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.FARPROC: ...
@winfunctype('KERNEL32.dll')
def LoadLibraryExA(lpLibFileName: win32more.Windows.Win32.Foundation.PSTR, hFile: win32more.Windows.Win32.Foundation.HANDLE, dwFlags: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS) -> win32more.Windows.Win32.Foundation.HMODULE: ...
@winfunctype('KERNEL32.dll')
def LoadLibraryExW(lpLibFileName: win32more.Windows.Win32.Foundation.PWSTR, hFile: win32more.Windows.Win32.Foundation.HANDLE, dwFlags: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS) -> win32more.Windows.Win32.Foundation.HMODULE: ...
LoadLibraryEx = UnicodeAlias('LoadLibraryExW')
@winfunctype('KERNEL32.dll')
def LoadResource(hModule: win32more.Windows.Win32.Foundation.HMODULE, hResInfo: win32more.Windows.Win32.Foundation.HRSRC) -> win32more.Windows.Win32.Foundation.HGLOBAL: ...
@winfunctype('KERNEL32.dll')
def LockResource(hResData: win32more.Windows.Win32.Foundation.HGLOBAL) -> VoidPtr: ...
@winfunctype('KERNEL32.dll')
def SizeofResource(hModule: win32more.Windows.Win32.Foundation.HMODULE, hResInfo: win32more.Windows.Win32.Foundation.HRSRC) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def AddDllDirectory(NewDirectory: win32more.Windows.Win32.Foundation.PWSTR) -> VoidPtr: ...
@winfunctype('KERNEL32.dll')
def RemoveDllDirectory(Cookie: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetDefaultDllDirectories(DirectoryFlags: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumResourceLanguagesExA(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PSTR, lpName: win32more.Windows.Win32.Foundation.PSTR, lpEnumFunc: win32more.Windows.Win32.System.LibraryLoader.ENUMRESLANGPROCA, lParam: IntPtr, dwFlags: UInt32, LangId: UInt16) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumResourceLanguagesExW(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PWSTR, lpName: win32more.Windows.Win32.Foundation.PWSTR, lpEnumFunc: win32more.Windows.Win32.System.LibraryLoader.ENUMRESLANGPROCW, lParam: IntPtr, dwFlags: UInt32, LangId: UInt16) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumResourceLanguagesEx = UnicodeAlias('EnumResourceLanguagesExW')
@winfunctype('KERNEL32.dll')
def EnumResourceNamesExA(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PSTR, lpEnumFunc: win32more.Windows.Win32.System.LibraryLoader.ENUMRESNAMEPROCA, lParam: IntPtr, dwFlags: UInt32, LangId: UInt16) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumResourceNamesExW(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PWSTR, lpEnumFunc: win32more.Windows.Win32.System.LibraryLoader.ENUMRESNAMEPROCW, lParam: IntPtr, dwFlags: UInt32, LangId: UInt16) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumResourceNamesEx = UnicodeAlias('EnumResourceNamesExW')
@winfunctype('KERNEL32.dll')
def EnumResourceTypesExA(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpEnumFunc: win32more.Windows.Win32.System.LibraryLoader.ENUMRESTYPEPROCA, lParam: IntPtr, dwFlags: UInt32, LangId: UInt16) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumResourceTypesExW(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpEnumFunc: win32more.Windows.Win32.System.LibraryLoader.ENUMRESTYPEPROCW, lParam: IntPtr, dwFlags: UInt32, LangId: UInt16) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumResourceTypesEx = UnicodeAlias('EnumResourceTypesExW')
@winfunctype('KERNEL32.dll')
def FindResourceW(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpName: win32more.Windows.Win32.Foundation.PWSTR, lpType: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRSRC: ...
FindResource = UnicodeAlias('FindResourceW')
@winfunctype('KERNEL32.dll')
def LoadLibraryA(lpLibFileName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HMODULE: ...
@winfunctype('KERNEL32.dll')
def LoadLibraryW(lpLibFileName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HMODULE: ...
LoadLibrary = UnicodeAlias('LoadLibraryW')
@winfunctype('KERNEL32.dll')
def EnumResourceNamesW(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PWSTR, lpEnumFunc: win32more.Windows.Win32.System.LibraryLoader.ENUMRESNAMEPROCW, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumResourceNames = UnicodeAlias('EnumResourceNamesW')
@winfunctype('KERNEL32.dll')
def EnumResourceNamesA(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PSTR, lpEnumFunc: win32more.Windows.Win32.System.LibraryLoader.ENUMRESNAMEPROCA, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def LoadPackagedLibrary(lpwLibFileName: win32more.Windows.Win32.Foundation.PWSTR, Reserved: UInt32) -> win32more.Windows.Win32.Foundation.HMODULE: ...
@winfunctype('api-ms-win-core-libraryloader-l2-1-0.dll')
def QueryOptionalDelayLoadedAPI(hParentModule: win32more.Windows.Win32.Foundation.HMODULE, lpDllName: win32more.Windows.Win32.Foundation.PSTR, lpProcName: win32more.Windows.Win32.Foundation.PSTR, Reserved: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def LoadModule(lpModuleName: win32more.Windows.Win32.Foundation.PSTR, lpParameterBlock: VoidPtr) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def FindResourceA(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpName: win32more.Windows.Win32.Foundation.PSTR, lpType: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRSRC: ...
@winfunctype('KERNEL32.dll')
def FindResourceExA(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PSTR, lpName: win32more.Windows.Win32.Foundation.PSTR, wLanguage: UInt16) -> win32more.Windows.Win32.Foundation.HRSRC: ...
@winfunctype('KERNEL32.dll')
def EnumResourceTypesA(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpEnumFunc: win32more.Windows.Win32.System.LibraryLoader.ENUMRESTYPEPROCA, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumResourceTypesW(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpEnumFunc: win32more.Windows.Win32.System.LibraryLoader.ENUMRESTYPEPROCW, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumResourceTypes = UnicodeAlias('EnumResourceTypesW')
@winfunctype('KERNEL32.dll')
def EnumResourceLanguagesA(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PSTR, lpName: win32more.Windows.Win32.Foundation.PSTR, lpEnumFunc: win32more.Windows.Win32.System.LibraryLoader.ENUMRESLANGPROCA, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EnumResourceLanguagesW(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PWSTR, lpName: win32more.Windows.Win32.Foundation.PWSTR, lpEnumFunc: win32more.Windows.Win32.System.LibraryLoader.ENUMRESLANGPROCW, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
EnumResourceLanguages = UnicodeAlias('EnumResourceLanguagesW')
@winfunctype('KERNEL32.dll')
def BeginUpdateResourceA(pFileName: win32more.Windows.Win32.Foundation.PSTR, bDeleteExistingResources: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('KERNEL32.dll')
def BeginUpdateResourceW(pFileName: win32more.Windows.Win32.Foundation.PWSTR, bDeleteExistingResources: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HANDLE: ...
BeginUpdateResource = UnicodeAlias('BeginUpdateResourceW')
@winfunctype('KERNEL32.dll')
def UpdateResourceA(hUpdate: win32more.Windows.Win32.Foundation.HANDLE, lpType: win32more.Windows.Win32.Foundation.PSTR, lpName: win32more.Windows.Win32.Foundation.PSTR, wLanguage: UInt16, lpData: VoidPtr, cb: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def UpdateResourceW(hUpdate: win32more.Windows.Win32.Foundation.HANDLE, lpType: win32more.Windows.Win32.Foundation.PWSTR, lpName: win32more.Windows.Win32.Foundation.PWSTR, wLanguage: UInt16, lpData: VoidPtr, cb: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
UpdateResource = UnicodeAlias('UpdateResourceW')
@winfunctype('KERNEL32.dll')
def EndUpdateResourceA(hUpdate: win32more.Windows.Win32.Foundation.HANDLE, fDiscard: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def EndUpdateResourceW(hUpdate: win32more.Windows.Win32.Foundation.HANDLE, fDiscard: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
EndUpdateResource = UnicodeAlias('EndUpdateResourceW')
@winfunctype('KERNEL32.dll')
def SetDllDirectoryA(lpPathName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('KERNEL32.dll')
def SetDllDirectoryW(lpPathName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
SetDllDirectory = UnicodeAlias('SetDllDirectoryW')
@winfunctype('KERNEL32.dll')
def GetDllDirectoryA(nBufferLength: UInt32, lpBuffer: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def GetDllDirectoryW(nBufferLength: UInt32, lpBuffer: win32more.Windows.Win32.Foundation.PWSTR) -> UInt32: ...
GetDllDirectory = UnicodeAlias('GetDllDirectoryW')
@winfunctype_pointer
def ENUMRESLANGPROCA(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PSTR, lpName: win32more.Windows.Win32.Foundation.PSTR, wLanguage: UInt16, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def ENUMRESLANGPROCW(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PWSTR, lpName: win32more.Windows.Win32.Foundation.PWSTR, wLanguage: UInt16, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
ENUMRESLANGPROC = UnicodeAlias('ENUMRESLANGPROCW')
@winfunctype_pointer
def ENUMRESNAMEPROCA(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PSTR, lpName: win32more.Windows.Win32.Foundation.PSTR, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def ENUMRESNAMEPROCW(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PWSTR, lpName: win32more.Windows.Win32.Foundation.PWSTR, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
ENUMRESNAMEPROC = UnicodeAlias('ENUMRESNAMEPROCW')
@winfunctype_pointer
def ENUMRESTYPEPROCA(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PSTR, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def ENUMRESTYPEPROCW(hModule: win32more.Windows.Win32.Foundation.HMODULE, lpType: win32more.Windows.Win32.Foundation.PWSTR, lParam: IntPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
ENUMRESTYPEPROC = UnicodeAlias('ENUMRESTYPEPROCW')
class ENUMUILANG(Structure):
    NumOfEnumUILang: UInt32
    SizeOfEnumUIBuffer: UInt32
    pEnumUIBuffer: POINTER(UInt16)
LOAD_LIBRARY_FLAGS = UInt32
DONT_RESOLVE_DLL_REFERENCES: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS = 1
LOAD_LIBRARY_AS_DATAFILE: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS = 2
LOAD_WITH_ALTERED_SEARCH_PATH: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS = 8
LOAD_IGNORE_CODE_AUTHZ_LEVEL: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS = 16
LOAD_LIBRARY_AS_IMAGE_RESOURCE: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS = 32
LOAD_LIBRARY_AS_DATAFILE_EXCLUSIVE: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS = 64
LOAD_LIBRARY_REQUIRE_SIGNED_TARGET: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS = 128
LOAD_LIBRARY_SEARCH_DLL_LOAD_DIR: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS = 256
LOAD_LIBRARY_SEARCH_APPLICATION_DIR: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS = 512
LOAD_LIBRARY_SEARCH_USER_DIRS: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS = 1024
LOAD_LIBRARY_SEARCH_SYSTEM32: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS = 2048
LOAD_LIBRARY_SEARCH_DEFAULT_DIRS: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS = 4096
LOAD_LIBRARY_SAFE_CURRENT_DIRS: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS = 8192
LOAD_LIBRARY_SEARCH_SYSTEM32_NO_FORWARDER: win32more.Windows.Win32.System.LibraryLoader.LOAD_LIBRARY_FLAGS = 16384
@winfunctype_pointer
def PGET_MODULE_HANDLE_EXA(dwFlags: UInt32, lpModuleName: win32more.Windows.Win32.Foundation.PSTR, phModule: POINTER(win32more.Windows.Win32.Foundation.HMODULE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PGET_MODULE_HANDLE_EXW(dwFlags: UInt32, lpModuleName: win32more.Windows.Win32.Foundation.PWSTR, phModule: POINTER(win32more.Windows.Win32.Foundation.HMODULE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
PGET_MODULE_HANDLE_EX = UnicodeAlias('PGET_MODULE_HANDLE_EXW')
class REDIRECTION_DESCRIPTOR(Structure):
    Version: UInt32
    FunctionCount: UInt32
    Redirections: POINTER(win32more.Windows.Win32.System.LibraryLoader.REDIRECTION_FUNCTION_DESCRIPTOR)
class REDIRECTION_FUNCTION_DESCRIPTOR(Structure):
    DllName: win32more.Windows.Win32.Foundation.PSTR
    FunctionName: win32more.Windows.Win32.Foundation.PSTR
    RedirectionTarget: VoidPtr


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Networking.NetworkListManager
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Ole
NA_DomainAuthenticationFailed: String = 'NA_DomainAuthenticationFailed'
NA_NetworkClass: String = 'NA_NetworkClass'
NA_NameSetByPolicy: String = 'NA_NameSetByPolicy'
NA_IconSetByPolicy: String = 'NA_IconSetByPolicy'
NA_DescriptionSetByPolicy: String = 'NA_DescriptionSetByPolicy'
NA_CategorySetByPolicy: String = 'NA_CategorySetByPolicy'
NA_NameReadOnly: String = 'NA_NameReadOnly'
NA_IconReadOnly: String = 'NA_IconReadOnly'
NA_DescriptionReadOnly: String = 'NA_DescriptionReadOnly'
NA_CategoryReadOnly: String = 'NA_CategoryReadOnly'
NA_AllowMerge: String = 'NA_AllowMerge'
NA_InternetConnectivityV4: String = 'NA_InternetConnectivityV4'
NA_InternetConnectivityV6: String = 'NA_InternetConnectivityV6'
NLM_MAX_ADDRESS_LIST_SIZE: UInt32 = 10
NLM_UNKNOWN_DATAPLAN_STATUS: UInt32 = 4294967295
class IEnumNetworkConnections(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{dcb00006-570f-4a9b-8d69-199fdba5723b}')
    @commethod(7)
    def get__NewEnum(self, ppEnumVar: POINTER(win32more.Windows.Win32.System.Ole.IEnumVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Next(self, celt: UInt32, rgelt: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.INetworkConnection), pceltFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Skip(self, celt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Clone(self, ppEnumNetwork: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.IEnumNetworkConnections)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumNetworks(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{dcb00003-570f-4a9b-8d69-199fdba5723b}')
    @commethod(7)
    def get__NewEnum(self, ppEnumVar: POINTER(win32more.Windows.Win32.System.Ole.IEnumVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Next(self, celt: UInt32, rgelt: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.INetwork), pceltFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Skip(self, celt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Clone(self, ppEnumNetwork: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.IEnumNetworks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INetwork(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{dcb00002-570f-4a9b-8d69-199fdba5723b}')
    @commethod(7)
    def GetName(self, pszNetworkName: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetName(self, szNetworkNewName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetDescription(self, pszDescription: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetDescription(self, szDescription: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetNetworkId(self, pgdGuidNetworkId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetDomainType(self, pNetworkType: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.NLM_DOMAIN_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetNetworkConnections(self, ppEnumNetworkConnection: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.IEnumNetworkConnections)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetTimeCreatedAndConnected(self, pdwLowDateTimeCreated: POINTER(UInt32), pdwHighDateTimeCreated: POINTER(UInt32), pdwLowDateTimeConnected: POINTER(UInt32), pdwHighDateTimeConnected: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_IsConnectedToInternet(self, pbIsConnected: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_IsConnected(self, pbIsConnected: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetConnectivity(self, pConnectivity: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetCategory(self, pCategory: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.NLM_NETWORK_CATEGORY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetCategory(self, NewCategory: win32more.Windows.Win32.Networking.NetworkListManager.NLM_NETWORK_CATEGORY) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INetwork2(ComPtr):
    extends: win32more.Windows.Win32.Networking.NetworkListManager.INetwork
    _iid_ = Guid('{b5550abb-3391-4310-804f-25dcc325ed81}')
    @commethod(20)
    def IsDomainAuthenticatedBy(self, domainAuthenticationKind: win32more.Windows.Win32.Networking.NetworkListManager.NLM_DOMAIN_AUTHENTICATION_KIND, pValue: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INetworkConnection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{dcb00005-570f-4a9b-8d69-199fdba5723b}')
    @commethod(7)
    def GetNetwork(self, ppNetwork: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.INetwork)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_IsConnectedToInternet(self, pbIsConnected: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_IsConnected(self, pbIsConnected: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetConnectivity(self, pConnectivity: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetConnectionId(self, pgdConnectionId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetAdapterId(self, pgdAdapterId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetDomainType(self, pDomainType: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.NLM_DOMAIN_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INetworkConnection2(ComPtr):
    extends: win32more.Windows.Win32.Networking.NetworkListManager.INetworkConnection
    _iid_ = Guid('{00e676ed-5a35-4738-92eb-8581738d0f0a}')
    @commethod(14)
    def IsDomainAuthenticatedBy(self, domainAuthenticationKind: win32more.Windows.Win32.Networking.NetworkListManager.NLM_DOMAIN_AUTHENTICATION_KIND, pValue: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INetworkConnectionCost(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{dcb0000a-570f-4a9b-8d69-199fdba5723b}')
    @commethod(3)
    def GetCost(self, pCost: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDataPlanStatus(self, pDataPlanStatus: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.NLM_DATAPLAN_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INetworkConnectionCostEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{dcb0000b-570f-4a9b-8d69-199fdba5723b}')
    @commethod(3)
    def ConnectionCostChanged(self, connectionId: Guid, newCost: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ConnectionDataPlanStatusChanged(self, connectionId: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INetworkConnectionEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{dcb00007-570f-4a9b-8d69-199fdba5723b}')
    @commethod(3)
    def NetworkConnectionConnectivityChanged(self, connectionId: Guid, newConnectivity: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def NetworkConnectionPropertyChanged(self, connectionId: Guid, flags: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTION_PROPERTY_CHANGE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INetworkCostManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{dcb00008-570f-4a9b-8d69-199fdba5723b}')
    @commethod(3)
    def GetCost(self, pCost: POINTER(UInt32), pDestIPAddr: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.NLM_SOCKADDR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDataPlanStatus(self, pDataPlanStatus: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.NLM_DATAPLAN_STATUS), pDestIPAddr: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.NLM_SOCKADDR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetDestinationAddresses(self, length: UInt32, pDestIPAddrList: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.NLM_SOCKADDR), bAppend: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INetworkCostManagerEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{dcb00009-570f-4a9b-8d69-199fdba5723b}')
    @commethod(3)
    def CostChanged(self, newCost: UInt32, pDestAddr: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.NLM_SOCKADDR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DataPlanStatusChanged(self, pDestAddr: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.NLM_SOCKADDR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INetworkEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{dcb00004-570f-4a9b-8d69-199fdba5723b}')
    @commethod(3)
    def NetworkAdded(self, networkId: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def NetworkDeleted(self, networkId: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def NetworkConnectivityChanged(self, networkId: Guid, newConnectivity: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def NetworkPropertyChanged(self, networkId: Guid, flags: win32more.Windows.Win32.Networking.NetworkListManager.NLM_NETWORK_PROPERTY_CHANGE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INetworkListManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{dcb00000-570f-4a9b-8d69-199fdba5723b}')
    @commethod(7)
    def GetNetworks(self, Flags: win32more.Windows.Win32.Networking.NetworkListManager.NLM_ENUM_NETWORK, ppEnumNetwork: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.IEnumNetworks)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetNetwork(self, gdNetworkId: Guid, ppNetwork: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.INetwork)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetNetworkConnections(self, ppEnum: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.IEnumNetworkConnections)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetNetworkConnection(self, gdNetworkConnectionId: Guid, ppNetworkConnection: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.INetworkConnection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_IsConnectedToInternet(self, pbIsConnected: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_IsConnected(self, pbIsConnected: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetConnectivity(self, pConnectivity: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetSimulatedProfileInfo(self, pSimulatedInfo: POINTER(win32more.Windows.Win32.Networking.NetworkListManager.NLM_SIMULATED_PROFILE_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def ClearSimulatedProfileInfo(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class INetworkListManagerEvents(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{dcb00001-570f-4a9b-8d69-199fdba5723b}')
    @commethod(3)
    def ConnectivityChanged(self, newConnectivity: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY) -> win32more.Windows.Win32.Foundation.HRESULT: ...
NLM_CONNECTION_COST = Int32
NLM_CONNECTION_COST_UNKNOWN: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTION_COST = 0
NLM_CONNECTION_COST_UNRESTRICTED: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTION_COST = 1
NLM_CONNECTION_COST_FIXED: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTION_COST = 2
NLM_CONNECTION_COST_VARIABLE: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTION_COST = 4
NLM_CONNECTION_COST_OVERDATALIMIT: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTION_COST = 65536
NLM_CONNECTION_COST_CONGESTED: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTION_COST = 131072
NLM_CONNECTION_COST_ROAMING: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTION_COST = 262144
NLM_CONNECTION_COST_APPROACHINGDATALIMIT: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTION_COST = 524288
NLM_CONNECTION_PROPERTY_CHANGE = Int32
NLM_CONNECTION_PROPERTY_CHANGE_AUTHENTICATION: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTION_PROPERTY_CHANGE = 1
NLM_CONNECTIVITY = Int32
NLM_CONNECTIVITY_DISCONNECTED: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY = 0
NLM_CONNECTIVITY_IPV4_NOTRAFFIC: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY = 1
NLM_CONNECTIVITY_IPV6_NOTRAFFIC: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY = 2
NLM_CONNECTIVITY_IPV4_SUBNET: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY = 16
NLM_CONNECTIVITY_IPV4_LOCALNETWORK: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY = 32
NLM_CONNECTIVITY_IPV4_INTERNET: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY = 64
NLM_CONNECTIVITY_IPV6_SUBNET: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY = 256
NLM_CONNECTIVITY_IPV6_LOCALNETWORK: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY = 512
NLM_CONNECTIVITY_IPV6_INTERNET: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTIVITY = 1024
class NLM_DATAPLAN_STATUS(Structure):
    InterfaceGuid: Guid
    UsageData: win32more.Windows.Win32.Networking.NetworkListManager.NLM_USAGE_DATA
    DataLimitInMegabytes: UInt32
    InboundBandwidthInKbps: UInt32
    OutboundBandwidthInKbps: UInt32
    NextBillingCycle: win32more.Windows.Win32.Foundation.FILETIME
    MaxTransferSizeInMegabytes: UInt32
    Reserved: UInt32
NLM_DOMAIN_AUTHENTICATION_KIND = Int32
NLM_DOMAIN_AUTHENTICATION_KIND_NONE: win32more.Windows.Win32.Networking.NetworkListManager.NLM_DOMAIN_AUTHENTICATION_KIND = 0
NLM_DOMAIN_AUTHENTICATION_KIND_LDAP: win32more.Windows.Win32.Networking.NetworkListManager.NLM_DOMAIN_AUTHENTICATION_KIND = 1
NLM_DOMAIN_AUTHENTICATION_KIND_TLS: win32more.Windows.Win32.Networking.NetworkListManager.NLM_DOMAIN_AUTHENTICATION_KIND = 2
NLM_DOMAIN_TYPE = Int32
NLM_DOMAIN_TYPE_NON_DOMAIN_NETWORK: win32more.Windows.Win32.Networking.NetworkListManager.NLM_DOMAIN_TYPE = 0
NLM_DOMAIN_TYPE_DOMAIN_NETWORK: win32more.Windows.Win32.Networking.NetworkListManager.NLM_DOMAIN_TYPE = 1
NLM_DOMAIN_TYPE_DOMAIN_AUTHENTICATED: win32more.Windows.Win32.Networking.NetworkListManager.NLM_DOMAIN_TYPE = 2
NLM_ENUM_NETWORK = Int32
NLM_ENUM_NETWORK_CONNECTED: win32more.Windows.Win32.Networking.NetworkListManager.NLM_ENUM_NETWORK = 1
NLM_ENUM_NETWORK_DISCONNECTED: win32more.Windows.Win32.Networking.NetworkListManager.NLM_ENUM_NETWORK = 2
NLM_ENUM_NETWORK_ALL: win32more.Windows.Win32.Networking.NetworkListManager.NLM_ENUM_NETWORK = 3
NLM_INTERNET_CONNECTIVITY = Int32
NLM_INTERNET_CONNECTIVITY_WEBHIJACK: win32more.Windows.Win32.Networking.NetworkListManager.NLM_INTERNET_CONNECTIVITY = 1
NLM_INTERNET_CONNECTIVITY_PROXIED: win32more.Windows.Win32.Networking.NetworkListManager.NLM_INTERNET_CONNECTIVITY = 2
NLM_INTERNET_CONNECTIVITY_CORPORATE: win32more.Windows.Win32.Networking.NetworkListManager.NLM_INTERNET_CONNECTIVITY = 4
NLM_NETWORK_CATEGORY = Int32
NLM_NETWORK_CATEGORY_PUBLIC: win32more.Windows.Win32.Networking.NetworkListManager.NLM_NETWORK_CATEGORY = 0
NLM_NETWORK_CATEGORY_PRIVATE: win32more.Windows.Win32.Networking.NetworkListManager.NLM_NETWORK_CATEGORY = 1
NLM_NETWORK_CATEGORY_DOMAIN_AUTHENTICATED: win32more.Windows.Win32.Networking.NetworkListManager.NLM_NETWORK_CATEGORY = 2
NLM_NETWORK_CLASS = Int32
NLM_NETWORK_IDENTIFYING: win32more.Windows.Win32.Networking.NetworkListManager.NLM_NETWORK_CLASS = 1
NLM_NETWORK_IDENTIFIED: win32more.Windows.Win32.Networking.NetworkListManager.NLM_NETWORK_CLASS = 2
NLM_NETWORK_UNIDENTIFIED: win32more.Windows.Win32.Networking.NetworkListManager.NLM_NETWORK_CLASS = 3
NLM_NETWORK_PROPERTY_CHANGE = Int32
NLM_NETWORK_PROPERTY_CHANGE_CONNECTION: win32more.Windows.Win32.Networking.NetworkListManager.NLM_NETWORK_PROPERTY_CHANGE = 1
NLM_NETWORK_PROPERTY_CHANGE_DESCRIPTION: win32more.Windows.Win32.Networking.NetworkListManager.NLM_NETWORK_PROPERTY_CHANGE = 2
NLM_NETWORK_PROPERTY_CHANGE_NAME: win32more.Windows.Win32.Networking.NetworkListManager.NLM_NETWORK_PROPERTY_CHANGE = 4
NLM_NETWORK_PROPERTY_CHANGE_ICON: win32more.Windows.Win32.Networking.NetworkListManager.NLM_NETWORK_PROPERTY_CHANGE = 8
NLM_NETWORK_PROPERTY_CHANGE_CATEGORY_VALUE: win32more.Windows.Win32.Networking.NetworkListManager.NLM_NETWORK_PROPERTY_CHANGE = 16
class NLM_SIMULATED_PROFILE_INFO(Structure):
    ProfileName: Char * 256
    cost: win32more.Windows.Win32.Networking.NetworkListManager.NLM_CONNECTION_COST
    UsageInMegabytes: UInt32
    DataLimitInMegabytes: UInt32
class NLM_SOCKADDR(Structure):
    data: Byte * 128
class NLM_USAGE_DATA(Structure):
    UsageInMegabytes: UInt32
    LastSyncTime: win32more.Windows.Win32.Foundation.FILETIME
NetworkListManager = Guid('{dcb00c01-570f-4a9b-8d69-199fdba5723b}')


make_ready(__name__)
